@@ -183,6 +183,7 @@ a_count_abnormal_by_baseline <- make_afun(
 count_abnormal_by_baseline <- function(lyt,
                                        var,
                                        abnormal,
+                                       nested = TRUE,
                                        ...,
                                        table_names = abnormal,
                                        .stats = NULL,
@@ -206,6 +207,7 @@ count_abnormal_by_baseline <- function(lyt,
       vars = var,
       var_labels = names(abn),
       afun = afun,
+      nested = nested,
       table_names = table_names[i],
       extra_args = c(list(abnormal = abn), list(...)),
       show_labels = "visible"
