@@ -356,6 +356,7 @@ a_count_abnormal_lab_worsen_by_baseline <- make_afun( # nolint
 #' @export
 count_abnormal_lab_worsen_by_baseline <- function(lyt, # nolint
                                                   var,
+                                                  nested = TRUE,
                                                   ...,
                                                   table_names = NULL,
                                                   .stats = NULL,
@@ -376,6 +377,7 @@ count_abnormal_lab_worsen_by_baseline <- function(lyt, # nolint
     lyt = lyt,
     vars = var,
     afun = afun,
+    nested = nested,
     extra_args = list(...),
     show_labels = "hidden"
   )
