@@ -14,7 +14,7 @@ NULL
 #' @describeIn count_patients_with_event Statistics function which counts the number of patients for which
 #'   the defined event has occurred.
 #'
-#' @inheritParams summarize_variables
+#' @inheritParams analyze_variables
 #' @param .var (`character`)\cr name of the column that contains the unique identifier.
 #' @param filters (`character`)\cr a character vector specifying the column names and flag variables
 #'   to be used for counting the number of unique identifiers satisfying such conditions.
@@ -144,12 +144,16 @@ a_count_patients_with_event <- make_afun(
 #' @export
 count_patients_with_event <- function(lyt,
                                       vars,
+                                      riskdiff = FALSE,
+                                      nested = TRUE,
                                       ...,
                                       table_names = vars,
                                       .stats = "count_fraction",
                                       .formats = NULL,
                                       .labels = NULL,
                                       .indent_mods = NULL) {
+  checkmate::assert_flag(riskdiff)
+
   afun <- make_afun(
     a_count_patients_with_event,
     .stats = .stats,
@@ -158,11 +162,23 @@ count_patients_with_event <- function(lyt,
     .indent_mods = .indent_mods
   )
 
+  extra_args <- if (isFALSE(riskdiff)) {
+    list(...)
+  } else {
+    list(
+      afun = list("s_count_patients_with_event" = afun),
+      .stats = .stats,
+      .indent_mods = .indent_mods,
+      s_args = list(...)
+    )
+  }
+
   analyze(
     lyt,
     vars,
-    afun = afun,
-    extra_args = list(...),
+    afun = ifelse(isFALSE(riskdiff), afun, afun_riskdiff),
+    nested = nested,
+    extra_args = extra_args,
     show_labels = ifelse(length(vars) > 1, "visible", "hidden"),
     table_names = table_names
   )
