@@ -162,6 +162,7 @@ a_proportion <- make_afun(
 #' @export
 estimate_proportion <- function(lyt,
                                 vars,
+                                nested = TRUE,
                                 ...,
                                 show_labels = "hidden",
                                 table_names = vars,
@@ -180,6 +181,7 @@ estimate_proportion <- function(lyt,
     lyt,
     vars,
     afun = afun,
+    nested = nested,
     extra_args = list(...),
     show_labels = show_labels,
     table_names = table_names
