@@ -3,7 +3,8 @@
 #' @description `r lifecycle::badge("stable")`
 #'
 #' Helper function that merges `ADSL` and `ADLB` datasets so that missing lab test records are inserted in the
-#' output dataset.
+#' output dataset. Remember that `na_level` must match the needed pre-processing
+#' done with [df_explicit_na()] to have the desired output.
 #'
 #' @param adsl (`data.frame`)\cr `ADSL` dataframe.
 #' @param adlb (`data.frame`)\cr `ADLB` dataframe.
@@ -137,7 +138,6 @@ h_adsl_adlb_merge_using_worst_flag <- function(adsl, # nolint
   adlb_out$ATOXGR <- as.factor(adlb_out$ATOXGR)
   adlb_out$BTOXGR <- as.factor(adlb_out$BTOXGR)
 
-  adlb_out <- df_explicit_na(adlb_out)
   formatters::var_labels(adlb_out) <- adlb_var_labels
 
   adlb_out
