@@ -62,15 +62,19 @@
 #' @export
 summarize_colvars <- function(lyt,
                               ...,
+                              na_level = NA_character_,
                               .stats = c("n", "mean_sd", "median", "range", "count_fraction"),
                               .formats = NULL,
                               .labels = NULL,
                               .indent_mods = NULL) {
-  afun <- create_afun_summary(.stats, .formats, .labels, .indent_mods)
+  extra_args <- list(.stats = .stats, na_level = na_level, ...)
+  if (!is.null(.formats)) extra_args[[".formats"]] <- .formats
+  if (!is.null(.labels)) extra_args[[".labels"]] <- .labels
+  if (!is.null(.indent_mods)) extra_args[[".indent_mods"]] <- .indent_mods
 
   analyze_colvars(
     lyt,
-    afun = afun,
-    extra_args = list(...)
+    afun = a_summary,
+    extra_args = extra_args
   )
 }
